@@ -27,6 +27,10 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: h323caps.h,v $
+ * Revision 1.40  2003/10/27 06:03:39  csoutheren
+ * Added support for QoS
+ *   Thanks to Henry Harrison of AliceStreet
+ *
  * Revision 1.39  2003/06/06 02:13:10  rjongbloed
  * Changed non-standard capability semantics so can use C style strings as
  *   the embedded data block (ie automatically call strlen)
@@ -439,6 +443,10 @@ class H323Capability : public PObject
 
     /// Get the payload type for the capaibility
     RTP_DataFrame::PayloadTypes GetPayloadType() const { return rtpPayloadType; }
+
+    /// Attach a QoS specification to this channel
+    virtual void AttachQoS(RTP_QOS *)
+    {}
   //@}
 
 #if PTRACING
@@ -570,6 +578,14 @@ class H323RealTimeCapability : public H323Capability
       const H245_H2250LogicalChannelParameters * param
                                       /// Parameters for channel
     ) const;
+
+    H323RealTimeCapability();
+    H323RealTimeCapability(const H323RealTimeCapability &rtc);
+    virtual ~H323RealTimeCapability();
+    void AttachQoS(RTP_QOS * _rtpqos);
+
+  protected:
+    RTP_QOS * rtpqos;
   //@}
 };
 
