@@ -27,6 +27,20 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: h323con.h,v $
+ * Revision 1.64  2003/12/28 02:38:14  csoutheren
+ * Added H323EndPoint::OnOutgoingCall
+ *
+ * Revision 1.63  2003/12/14 10:42:29  rjongbloed
+ * Changes for compilability without video support.
+ *
+ * Revision 1.62  2003/10/27 06:03:38  csoutheren
+ * Added support for QoS
+ *   Thanks to Henry Harrison of AliceStreet
+ *
+ * Revision 1.61  2003/10/09 09:47:45  csoutheren
+ * Fixed problem with re-opening RTP half-channels under unusual
+ * circumstances. Thanks to Damien Sandras
+ *
  * Revision 1.60  2003/04/30 00:28:50  robertj
  * Redesigned the alternate credentials in ARQ system as old implementation
  *   was fraught with concurrency issues, most importantly it can cause false
@@ -256,6 +270,7 @@
 #include "transports.h"
 #include "channels.h"
 #include "guid.h"
+#include "openh323buildopts.h"
 
 
 /* The following classes have forward references to avoid including the VERY
@@ -1043,7 +1058,7 @@ class H323Connection : public PObject
        If FALSE is returned the connection is aborted and a Release Complete
        PDU is sent.
 
-       The default behaviour simply returns TRUE.
+       The default behaviour calls H323EndPoint::OnOutgoingCall
      */
     virtual BOOL OnOutgoingCall(
       const H323SignalPDU & connectPDU   /// Received Connect PDU
@@ -1454,8 +1469,9 @@ class H323Connection : public PObject
       const H323Capability & capability, /// Capability creating channel
       H323Channel::Directions dir,       /// Direction of channel
       unsigned sessionID,                /// Session ID for RTP channel
-      const H245_H2250LogicalChannelParameters * param
+      const H245_H2250LogicalChannelParameters * param,
                                          /// Parameters for channel
+      RTP_QOS * rtpqos = NULL            /// QoS for RTP
     );
 
     /**This function is called when the remote endpoint want's to create
@@ -1806,9 +1822,9 @@ class H323Connection : public PObject
       unsigned sessionID
     ) const;
 
-    /**Use an RTP session for the specified ID.
+    /**Use an RTP session for the specified ID and for the given direction.
        If there is no session of the specified ID, a new one is created using
-       the information prvided in the H245_TransportAddress PDU. If the system
+       the information provided in the H245_TransportAddress PDU. If the system
        does not support the specified transport, NULL is returned.
 
        If this function is used, then the ReleaseSession() function MUST be
@@ -1817,7 +1833,9 @@ class H323Connection : public PObject
       */
     virtual RTP_Session * UseSession(
       unsigned sessionID,
-      const H245_TransportAddress & pdu
+      const H245_TransportAddress & pdu,
+      H323Channel::Directions dir,
+      RTP_QOS * rtpqos = NULL
     );
 
     /**Release the session. If the session ID is not being used any more any
