@@ -27,6 +27,13 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: h323caps.cxx,v $
+ * Revision 1.68  2003/11/08 03:11:29  rjongbloed
+ * Fixed failure to call ancestor in copy ctor, thanks  Victor Ivashin.
+ *
+ * Revision 1.67  2003/10/27 06:03:39  csoutheren
+ * Added support for QoS
+ *   Thanks to Henry Harrison of AliceStreet
+ *
  * Revision 1.66  2003/06/06 02:13:48  rjongbloed
  * Changed non-standard capability semantics so can use C style strings as
  *   the embedded data block (ie automatically call strlen)
@@ -431,12 +438,42 @@ BOOL H323Capability::IsUsable(const H323Connection &) const
 
 /////////////////////////////////////////////////////////////////////////////
 
+H323RealTimeCapability::H323RealTimeCapability()
+{
+    rtpqos = NULL;
+}
+
+H323RealTimeCapability::H323RealTimeCapability(const H323RealTimeCapability & rtc)
+  : H323Capability(rtc)
+{
+  if (rtc.rtpqos == NULL) 
+    rtpqos = NULL;
+  else {
+    rtpqos  = new RTP_QOS();
+    *rtpqos = *rtc.rtpqos;
+  }
+}
+
+H323RealTimeCapability::~H323RealTimeCapability()
+{
+  if (rtpqos != NULL)
+    delete rtpqos;
+}
+
+void H323RealTimeCapability::AttachQoS(RTP_QOS * _rtpqos)
+{
+  if (rtpqos != NULL)
+    delete rtpqos;
+    
+  rtpqos = _rtpqos;
+}
+
 H323Channel * H323RealTimeCapability::CreateChannel(H323Connection & connection,
                                                     H323Channel::Directions dir,
                                                     unsigned sessionID,
                                  const H245_H2250LogicalChannelParameters * param) const
 {
-  return connection.CreateRealTimeLogicalChannel(*this, dir, sessionID, param);
+  return connection.CreateRealTimeLogicalChannel(*this, dir, sessionID, param, rtpqos);
 }
 
 
